==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/eventing/v1beta1/EventTypeListBuilder.java <==
package io.fabric8.knative.eventing.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class EventTypeListBuilder extends EventTypeListFluentImpl<EventTypeListBuilder> implements VisitableBuilder<EventTypeList,EventTypeListBuilder> {

    EventTypeListFluent<?> fluent;
    Boolean validationEnabled;

    public EventTypeListBuilder() { 
        this(true);
    }


    public EventTypeListBuilder(Boolean validationEnabled) { 
        this(new EventTypeList(), validationEnabled);
    }


    public EventTypeListBuilder(EventTypeListFluent<?> fluent) { 
        this(fluent, true);
    }


    public EventTypeListBuilder(EventTypeListFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new EventTypeList(), validationEnabled);
    }


    public EventTypeListBuilder(EventTypeListFluent<?> fluent,EventTypeList instance) { 
        this(fluent, instance, true);
    }


    public EventTypeListBuilder(EventTypeListFluent<?> fluent,EventTypeList instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public EventTypeListBuilder(EventTypeList instance) { 
        this(instance,true);
    }


    public EventTypeListBuilder(EventTypeList instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public EventTypeList build() {
        EventTypeList buildable = new EventTypeList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        EventTypeListBuilder that = (EventTypeListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/eventing/v1beta1/EventTypeListBuilder.java <==
package io.fabric8.knative.eventing.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class EventTypeListBuilder extends EventTypeListFluentImpl<EventTypeListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<EventTypeList,EventTypeListBuilder> {

    EventTypeListFluent<?> fluent;
    Boolean validationEnabled;

    public EventTypeListBuilder() {
        this(true);
    }

    public EventTypeListBuilder(Boolean validationEnabled) {
        this(new EventTypeList(), validationEnabled);
    }

    public EventTypeListBuilder(EventTypeListFluent<?> fluent) {
        this(fluent, true);
    }

    public EventTypeListBuilder(EventTypeListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new EventTypeList(), validationEnabled);
    }

    public EventTypeListBuilder(EventTypeListFluent<?> fluent,EventTypeList instance) {
        this(fluent, instance, true);
    }

    public EventTypeListBuilder(EventTypeListFluent<?> fluent,EventTypeList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public EventTypeListBuilder(EventTypeList instance) {
        this(instance,true);
    }

    public EventTypeListBuilder(EventTypeList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.v1beta1.EditableEventTypeList build() {
        EditableEventTypeList buildable = new EditableEventTypeList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        EventTypeListBuilder that = (EventTypeListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
